# Contributor License Agreement

Thank you for your interest in contributing to the Verge CLI project ("Project"), owned and maintained by Verge.io ("Company"). This Contributor License Agreement ("Agreement") documents the rights granted by contributors to the Company.

By submitting a Contribution to this Project, you accept and agree to the following terms and conditions.

## 1. Definitions

**"Contribution"** means any original work of authorship, including any modifications or additions to an existing work, that you intentionally submit to the Project for inclusion. "Submit" means any form of communication sent to the Project (e.g., pull requests, issues, comments), but excluding communications marked "Not a Contribution."

**"You" (or "Your")** means the individual or legal entity making the Contribution.

## 2. Grant of Copyright License

You hereby grant to the Company and recipients of software distributed by the Company a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare derivative works of, publicly display, publicly perform, sublicense, and distribute Your Contributions and such derivative works.

## 3. Grant of Patent License

You hereby grant to the Company and recipients of software distributed by the Company a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Contribution, where such license applies only to those patent claims licensable by You that are necessarily infringed by Your Contribution alone or by combination of Your Contribution with the Project.

## 4. Representations

You represent that:

- Each Contribution is Your original creation, or You have sufficient rights to grant the licenses in this Agreement.
- Your Contribution does not violate any third party's intellectual property or other rights.
- If Your employer has rights to intellectual property that You create, You have received permission to make Contributions on behalf of that employer, or Your employer has waived such rights.

## 5. No Support Obligation

You are not expected to provide support for Your Contributions, except to the extent You desire to do so.

## 6. Agreement

By submitting a pull request or other Contribution to this Project, you signify your agreement to these terms. If you are making a Contribution on behalf of your employer, you represent that you have the authority to agree to these terms on their behalf.
